// ChooseTargetDialogTableCellRenderer.java created on 12 March 2004 at 11:55

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.table.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

import kea.programs.*;
import kea.database.*;
import kea.programs.dialogBoxes.databaseDialog.Info;
import kea.programs.icons.KeaIcon;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 TableCellRender for ChooseTargetDialog class.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class ChooseTargetDialogTableCellRenderer extends DefaultTableCellRenderer {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public ChooseTargetDialogTableCellRenderer() {
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Overridden DefaultTableCellRenderer method.
	 */
	public Component getTableCellRendererComponent(
		JTable table,
		Object value,
		boolean isSelected,
		boolean hasFocus,
		int row, 
		int column
		) {
		
		// Get component, after changes have been made by base class.
		Component c = super.getTableCellRendererComponent(
			table,
			value, 
			isSelected, 
			hasFocus, 
			row, 
			column
			);		
		
		// Make modifications, BUT only if value object is a Record object.
		// (Should be if renderer has been registered correctly with Table.)
		if (value instanceof Record) {
			
			Record record = (Record)value;
			JLabel label = (JLabel)c;
			label.setText(record.getName());
			label.setIcon(getSelectionIcon(record));
		
			}
		

		return c;
			
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	// Returns icon on basis of selectin status of supplied record.
	private ImageIcon getSelectionIcon(Record record) {
		
		RecordStatus selectionStatus = record.getSelectionStatus();
		RecordType type = record.getRecordType();
		
		// Action if marked a target.
		if (type == RecordType.Target) {
			
			if (selectionStatus == RecordStatus.Selected) {
				return KeaIcon.Target.getImageIcon();
				}
			
			if (selectionStatus == RecordStatus.PartiallySelected) {
				return KeaIcon.PartiallySelectedTarget.getImageIcon();
				}
			
			}
		
		// Action if a node (taxon).
		if (!record.isLeaf()) {
			
			if (selectionStatus == RecordStatus.NotSelected) {
				return Info.CLOSED_NONE_SELECTED_ICON;
				}
			else if (selectionStatus == RecordStatus.Selected) {
				return Info.CLOSED_ALL_SELECTED_ICON;
				}
			else if (selectionStatus == RecordStatus.PartiallySelected) {
				return Info.CLOSED_SOME_SELECTED_ICON;
				}
			
			} // End of if.
		
		// Action if a leaf (organism entry).
		else {
			
			if (selectionStatus == RecordStatus.NotSelected) {
				return Info.RECORD_NOT_SELECTED_ICON;
				}
			else if (selectionStatus == RecordStatus.Selected) {
				return Info.RECORD_ICON;
				}
				
			} // End of else.
		
		return null;
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
