// ChooseTargetDialogTableModel.java created on 07 March 2004 at 11:27

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;
import javax.swing.table.*;
import javax.swing.*;
import java.io.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Table model for ChooseTargetDialog.
 @author  Kevin Ashelford.
 @version 2.17.
 */
class ChooseTargetDialogTableModel extends AbstractTableModel {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	// Column names used by AbstractTreeModel getColumnName() method.
	private String[] _columnNames;
	// Column Class types used by AbstractTreeModel getColumnClass() method.
	private Class[] _columnClasses;
	
	private Vector _children;
	private Record _record;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 @param record Record object that will supply data.
	 */
	public ChooseTargetDialogTableModel(Record record) {
		
		_columnNames = new String[]{
			"Name", 
			"Code",
			"Source"
			};
		_columnClasses = new Class[] {
			Record.class,
			String.class,
			String.class
			};
			
		updateModel(record);	
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Update model with new Record object.
	 @param record Record object containing data to display in table.
	 */
	public void updateModel(Record record) {
		_record = record;
		_children = _record.getChildren();
		fireTableChanged(null);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns current Record object (supplying data) associated with model.
	 @return Record object.
	 */
	public Record getCurrentRecord() {
		return _record;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	// Gets source name from File object associated with Record object.
	private String getSourceName(Record record) {
		return kea.util.FileIO.getNameWithoutSuffix(record.getSource());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AbstractTableModel method.
	 @return Number of columns.
	 */
	public int getColumnCount() {
		return _columnClasses.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementaion of AbstractTableModel method.
	 @return Number of rows.
	 */
	public int getRowCount() {
		return _children.size();
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AstractTableModel method.
	 @param rowIndex Row index number for cell.
	 @param columnIndex Column index number for cell.
	 @return Object.
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		
		Record child = (Record)_children.get(rowIndex);
		
		switch (columnIndex) {
			
			case 0: return child;
			case 1: return child.getCode();
			case 2: return getSourceName(child);
		
			default: return null;
			
			} // End of switch.
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////

	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Column name as a String.
	 */
	public String getColumnName(int columnIndex) {
		return _columnNames[columnIndex];
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Class object for column.
	 */
	public Class getColumnClass(int columnIndex) {
		return _columnClasses[columnIndex];
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Sets widths of columns.
	 @param table JTable object within which columns will be displayed.
	 */
	public void setColumnWidths(JTable table) {
		
		TableColumnModel model = table.getColumnModel();
		
		// NOTE:
		// Done the following way to avoid complications if/when new columns
		// are added and the order changed.
		
		TableColumn column = null;
		String name = null;
		Enumeration columns = model.getColumns();
		while(columns.hasMoreElements()) {
			
			column = ((TableColumn)columns.nextElement());
			name = ((String)column.getHeaderValue());
			
			if (name.equals("Name")) {
				column.setPreferredWidth(210);
				}
			
			if (name.equals("Code")) {
				column.setPreferredWidth(75);
				}
			
			if (name.equals("Source")) {
				column.setPreferredWidth(95);
				}
			
			} // End of while loop.
		
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
