// TableModel.java created on 13 January 2004 at 16:21

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;
import javax.swing.table.*;
import javax.swing.*;
import java.io.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Table model for FindOligosDialog dialog box.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class FindOligosDialogTableModel extends AbstractTableModel {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	// Column names used by AbstractTreeModel getColumnName() method.
	private final String[] _columnNames;
	// Column Class types used by AbstractTreeModel getColumnClass() method.
	private final Class[] _columnClasses;
	
	private final TargetCollection _targetCollection;
	
	protected static final int NUMBER_COLUMN = 0;
	protected static final int NAME_COLUMN = 1;
	protected static final int CODE_COLUMN = 2;
	protected static final int SOURCE_COLUMN = 3;
	protected static final int CHECKBOX_COLUMN = 4;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 @param targetCollection Targets to display.
	 */
	public FindOligosDialogTableModel(final TargetCollection targetCollection) {
		
		_columnNames = new String[]{
			"No.",
			"Name", 
			"Code",
			"Source",
			"Design from?"
			};
		_columnClasses = new Class[] {
			Integer.class,
			Record.class,
			String.class,
			String.class,
			Target.class
			};
			
		_targetCollection = targetCollection;	
		
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Overrides method to ensure checkbox column is editable.
	 @param row Row number.
	 @param column Column number.
	 @return True is cell is editable.
	 */
	public boolean isCellEditable(int row, int column) {
		if (column == CHECKBOX_COLUMN) { 
		  return true;
			}
		return false;
		} 
	
	////////////////////////////////////////////////////////////////////////////
	
	// Gets source name from File object associated with Record object.
	private String getSourceName(final Record record) {
		return kea.util.FileIO.getNameWithoutSuffix(record.getSource());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AbstractTableModel method.
	 @return Number of columns.
	 */
	public int getColumnCount() {
		return _columnClasses.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementaion of AbstractTableModel method.
	 @return Number of rows.
	 */
	public int getRowCount() {
		return _targetCollection.getSize();
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AstractTableModel method.
	 @param rowIndex Row index number for cell.
	 @param columnIndex Column index number for cell.
	 @return Object.
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		
		Target target = _targetCollection.getTarget(rowIndex);

		switch (columnIndex) {
			
			case 0: return new Integer(rowIndex + 1);
			case 1: return target.getRecord();
			case 2: return target.getRecord().getCode();
			case 3: return getSourceName(target.getRecord());
			case 4: return target; 
		
			default: return null;
			
			} // End of switch.
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////

	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Column name as a String.
	 */
	public String getColumnName(int columnIndex) {
		return _columnNames[columnIndex];
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Class object for column.
	 */
	public Class getColumnClass(int columnIndex) {
		return _columnClasses[columnIndex];
		} // End of method.

	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
