// FloatTableCellRenderer.java created on 31 May 2004 at 11:22

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.table.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

import kea.programs.*;
import kea.database.*;
import kea.programs.icons.KeaIcon;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 TableCellRender for Float objects.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class FloatTableCellRenderer extends DefaultTableCellRenderer {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	private final java.text.NumberFormat _numberFormat;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public FloatTableCellRenderer() {
		
		// Initialise NumberFormat for rounding up float numbers.	
		_numberFormat = java.text.NumberFormat.getInstance();
		_numberFormat.setMinimumFractionDigits(1);
		_numberFormat.setMaximumFractionDigits(1);	
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Overridden DefaultTableCellRenderer method.
	 @param table JTable object.
	 @param value To be cast as Record object.
	 @param isSelected True if selected.
	 @param hasFocus True if has focus.
	 @param row Row number.
	 @param column Column number.
	 @return Component object.
	 */
	public Component getTableCellRendererComponent(
		JTable table,
		Object value,
		boolean isSelected,
		boolean hasFocus,
		int row, 
		int column
		) {
		
		// Get component, after changes have been made by base class.
		Component c = super.getTableCellRendererComponent(
			table,
			value, 
			isSelected, 
			hasFocus, 
			row, 
			column
			);		
		
		if (value instanceof Float) {
			
			Float number = (Float)value;
			JLabel label = (JLabel)c;
			label.setText(_numberFormat.format(number));
			label.setHorizontalAlignment(label.CENTER);
			}
		
		return c;
			
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////+