// OligoDesignInfo.java created on 17 May 2004 at 11:22

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Simple class for storing oligo design information (generated by 
 FindOligosDialog for display by SearchDatabaseDialog.)
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class OligoDesignInfo {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private final int _maxDegeneracy;
	private final int _oligoLength;
	private final int _total;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>OligoDesignInfo</code>.
	 @param maxDegeneracy Maximum number of degenerate bases in designed oligos, 
	 as specified by the user.
	 @param oligoLength Length of oligos, as specified by user.
	 @param total Total number of oligos identified.
	 */
	public OligoDesignInfo(
		final int maxDegeneracy,
		final int oligoLength,
		final int total
		) {
		
		_maxDegeneracy = maxDegeneracy;
		_oligoLength = oligoLength;
		_total = total;
			
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	/**
	 Returns the maximum number of degenerate bases allowed, as specified by the 
	 user.
	 @return Maximum degeneracy.
	 */
	public int getMaximumDegeneracy() {
		return _maxDegeneracy;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns the oligonucleotide length specified by the user.
	 @return Oligonucleotide length.
	 */
	public int getOligoLength() {
		return _oligoLength;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns total number of oligos identified by program.
	 */
	public int getTotalOligos() {
		return _total;
		} // End of method.
	
	//##########################################################################
	
	// METHODS
	
	//##########################################################################
	
	// INNER CLASSES
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
