// OligoSearchResultCollection.java created on 17 May 2004 at 14:58

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Collection of OligoSearchResult objects, generated by SearchDatabase.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class OligoSearchResultCollection {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	// Key=Oligo, value=OligoSearchResult.
	private final HashMap _hashStore;
	private final ArrayList _arrayStore;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>OligoSearchResultCollection</code>.
	 */
	public OligoSearchResultCollection() {
		_hashStore = new HashMap();
		_arrayStore = new ArrayList();
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Add OligoSearchResult object to collection.
	 @param oligoSearchResult Search result to add to collection.
	 */
	public void addOligoSearchResult(final OligoSearchResult oligoSearchResult) {
		_hashStore.put(
			oligoSearchResult.getOligo(), 
			oligoSearchResult
			);
		_arrayStore.add(oligoSearchResult);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
		
	/**
	 Returns OligoSearchResult object corresponding to Oligo object supplied.
	 @param oligo Oligo object.
	 @return OligoSearchResult object.
	 */
	public OligoSearchResult getOligoSearchResult(final Oligo oligo) {
		
		return (OligoSearchResult)_hashStore.get(oligo);
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns OligoSearchResult object corresponding to index number supplied.
	 @param index Index number of required OligoSearchResult object.
	 @return OligoSearchResult object.
	 */
	public OligoSearchResult getOligoSearchResult(final int index) {
		
		return (OligoSearchResult)_arrayStore.get(index);
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns array of oligo search result objects.
	 @return Array of oligo search objects.
	 */
	public OligoSearchResult[] getOligoSearchResults() {
		
		OligoSearchResult[] results = 
			new OligoSearchResult[_arrayStore.size()];
		
		_arrayStore.toArray(results);
		
		return results;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns size of collection.
	 @return Number of OligoSearchResult objects stored in collection.
	 */
	public int getSize() {
		return _hashStore.size();
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASSES
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
