// PrimroseOligoDatabase.java created on 14 May 2004 at 11:47

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Stores OligoCollection objects.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class PrimroseOligoDatabase {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private final ArrayList _collections;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>PrimroseOligoDatabase</code>.
	 */
	public PrimroseOligoDatabase() {
		_collections = new ArrayList();
		} // End of constructor.
	
	//##########################################################################
		
	// METHODS
	
	/**
	 Adds an OligoCollection object to database.
	 @param oligoCollection OligoCollection object to add.
	 */
	public void addOligoCollection(final OligoCollection oligoCollection) {
		_collections.add(oligoCollection);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns OligoCollection object corresponding to index number.
	 @param index Index number of OligoCollection object.
	 @return OligoCollection object.
	 */
	public OligoCollection getOligoCollection(final int index) {
		return (OligoCollection)_collections.get(index);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns an array of all Oligo objects stored in database.
	 @return Array of Oligo objects.
	 */
	public PrimroseOligo[] getOligos() {
		
		ArrayList buffer = new ArrayList();
		
		for(int i = 0; i < _collections.size(); i++) {
			OligoCollection oc = (OligoCollection)_collections.get(i);
			for(int j = 0; j < oc.getSize(); j++) {
				buffer.add((PrimroseOligo)oc.getOligo(j));
				}
			}
		
		PrimroseOligo[] oligos = new PrimroseOligo[buffer.size()];
		buffer.toArray(oligos);
		return oligos;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns number of OligoCollections in database.
	 @return Size of database.
	 */
	public int getNumberOfCollections() {
		return _collections.size();
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns total number of oligo objects in database (the sum of all 
	 OligoCollection sizes).
	 @return Total number of Oligo objects.
	 */
	public int getTotalNumberOfOligos() {
		
		int counter = 0;
		
		for (int i = 0; i < _collections.size(); i++) {
			counter += ((OligoCollection)_collections.get(i)).getSize();
			}
		
		return counter;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns number of Oligo objects within a specified Oligo collection.
	 @param index Index number of oligo collection to check.
	 @return Number of Oligo objects within oligo collection.
	 */
	public int getNumberOfOligos(int index) {
		return ((OligoCollection)_collections.get(index)).getSize();
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASSES
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
