// PrimroseTreeCellRenderer.java created on 27 May 2004 at 12:39

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.tree.*;
import javax.swing.*;
import java.awt.*;

import kea.programs.*;
import kea.database.*;
import kea.graphics.Colour;
import kea.programs.icons.KeaIcon;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Default TreeCellRenderer for Primrose trees.
 @author  Kevin Ashelford.
 @version 2.17.
 */
class PrimroseTreeCellRenderer extends DefaultTreeCellRenderer {
	
	//##########################################################################
	
	// MEMBER FIELDS

	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public PrimroseTreeCellRenderer() {
		
		super.setBackgroundSelectionColor(Colour.BackgroundSelection);
		
		// Necessary to prevent problems with display.
		super.setTextNonSelectionColor(Color.BLACK);
		super.setTextSelectionColor(Color.BLACK);
		
		} // End of constructor.
	
	//##########################################################################
	
// METHODS
	
	/**
	 Overriden base method.
	 @param tree JTree.
	 @param value TreeNode.
	 @param selected Is node selected?
	 @param expanded Is node expanded?
	 @param leaf Is node a leaf?
	 @param row Tree row.
	 @param hasFocus Has focus?
	 @return Component.
	 */
	public Component getTreeCellRendererComponent(
		JTree tree,
		Object value,
		boolean selected,
		boolean expanded,
		boolean leaf,
		int row,
		boolean hasFocus
		) {
		
		// Only want to change icons!	
		super.getTreeCellRendererComponent(
			tree, 
			value, 
			selected, 
			expanded, 
			leaf, 
			row, 
			hasFocus
			);
		
		// On basis of record selection status choose icon image to display.
		Record r = (Record)value;
		if (r.getSelectionStatus() == RecordStatus.Selected) {
			
			if (r.getRecordType() == RecordType.Target) {
				selectedTargetRecord(expanded, leaf);
				}
			else {
				selectedRecord(expanded, leaf);
				}
			
			}
		else if (r.getSelectionStatus() == RecordStatus.PartiallySelected) {
			
			if (r.getRecordType() == RecordType.Target) {
				partiallySelectedTargetRecord(expanded);
				}
			else {
				partiallySelectedRecord(expanded);
				}
		
			}
		else {
			notSelectedRecord(expanded, leaf);
			}
		
		return this;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void selectedRecord(boolean expanded, boolean leaf) {
		
		if (expanded) {
			this.setIcon(KeaIcon.OpenAllSelected.getImageIcon());
			}
		else if (leaf) {
			this.setIcon(KeaIcon.Record.getImageIcon());
			}
		else {
			this.setIcon(KeaIcon.ClosedAllSelected.getImageIcon());
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void selectedTargetRecord(boolean expanded, boolean leaf) {
		
		if (expanded) {
			this.setIcon(KeaIcon.TargetOpenAllSelected.getImageIcon());
			}
		else if (leaf) {
			this.setIcon(KeaIcon.TargetRecord.getImageIcon());
			}
		else {
			this.setIcon(KeaIcon.TargetClosedAllSelected.getImageIcon());
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void partiallySelectedRecord(boolean expanded) {
		
		if (expanded) {
			this.setIcon(KeaIcon.OpenSomeSelected.getImageIcon());
			}
		else {
			this.setIcon(KeaIcon.ClosedSomeSelected.getImageIcon());
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void partiallySelectedTargetRecord(boolean expanded) {
		
		if (expanded) {
			this.setIcon(KeaIcon.TargetOpenSomeSelected.getImageIcon()); 
			}
		else {
			this.setIcon(KeaIcon.TargetClosedSomeSelected.getImageIcon()); 
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void notSelectedRecord(boolean expanded, boolean leaf) {
		
		if (expanded) {
			this.setIcon(KeaIcon.OpenNoneSelected.getImageIcon());
			}
		else if (leaf) {
			this.setIcon(KeaIcon.RecordNotSelected.getImageIcon());
			}
		else {
			this.setIcon(KeaIcon.ClosedNoneSelected.getImageIcon());
			}
		
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
