// ProjectFileFilter.java created on 07 March 2004 at 14:15

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.io.File;
import javax.swing.filechooser.FileFilter;
import kea.programs.fileFilters.*;
import kea.io.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 File filter for project files.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public final class ProjectFileFilter extends KeaFileFilter {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	/**Suffix for oligo files.*/
	private String EXTENSION = "ppf";
	/**Brief description of oligo file suffix.*/
	private String DESCRIPTION = "Primrose project file";
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public ProjectFileFilter() {
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	/**
	 Gets description for file filter.
	 @see FileFilter#getDescription
	 @return Description.
	 */
	public String getDescription() {
		
		return DESCRIPTION + " (*." + EXTENSION + ")";
		
		} // End of property.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Gets extension for files.
	 @return Suffix String.
	 */
	public String getExtension() {
		
		return EXTENSION;
		
		} // End of property.
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Method used by JFileChooser object.
	 
	 In this implementation, returns true if supplied file object has the 
	 correct extension (.ppf).
	 
	 @param f File object.
	 @see FileFilter#accept
	 @return True if suitable file.
	 */
	public boolean accept(File f) {
		
		// Always allow directories, regardless of extensions.
		if (f.isDirectory()) {return true;}
		
		// Check file is ok.
		String filename = f.getName().toLowerCase();
		if ( filename.endsWith(EXTENSION) ) {
			return true;
			}
		
		return false;
		
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
