// ReportGraphTableDialog.java created on 29 May 2004 at 10:37

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.awt.*;
import javax.swing.*;

import kea.programs.plot.*;
import kea.graphics.Colour;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Table dialog for displaying graph data.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class ReportGraphTableDialog extends JDialog {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	private JTable _table;

	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Create new instance of class.
	 @param owner Dialog owner.
	 @param modal Decide modal status.
	 */
	public ReportGraphTableDialog(JDialog owner, boolean modal) {
		
		super(owner, modal);

		initialise();
		
		} // End of constructor.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Create new instance of class.
	 @param owner Frame owner.
	 @param modal Decide modal status.
	 */
	public ReportGraphTableDialog(JFrame owner, boolean modal) {
		
		super(owner, modal);

		initialise();
		
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS

	private void initialise() {
		
		this.setTitle("Graph Data");

		// Create table object.
		_table = new JTable(new ReportGraphTableModel());

		_table.setSelectionBackground(Colour.BackgroundSelection);
		_table.setSelectionForeground(Color.BLACK);

		// Add to dialog with scroll pane (only way of getting titles?  Why?).
		JScrollPane sp = new JScrollPane(_table);
		
		// Sets scrollpane background to white.
		sp.getViewport().setBackground(Color.WHITE);
		this.getContentPane().add(sp);
		_table.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);

		// Set size (Would have preferred pack() but scroll pane interferes - why?).
		this.setSize(300, 180);

		// Center in screen.
		kea.util.GUIUtils.setLocationOnceSized(this);
		
		} // end of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Update display.
	 @param collections Data to display.
	 */
	public void update(CoordinateCollection[] collections) {
		ReportGraphTableModel model = (ReportGraphTableModel)_table.getModel(); 
		model.updateModel(collections);
		} 

	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Clear display.
	 */
	public void clear() {
		ReportGraphTableModel model = (ReportGraphTableModel)_table.getModel(); 
		model.updateModel(model.NULL_DATA);
		} 

	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
