// ReportTableCellRenderer.java created on 26 May 2004 at 17:30

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.table.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

import kea.programs.*;
import kea.database.*;
import kea.programs.icons.KeaIcon;


////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 TableCellRender for Report table.
 @author  Kevin Ashelford.
 @version 2.17.
 */
class ReportTableCellRenderer extends DefaultTableCellRenderer {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public ReportTableCellRenderer() {
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Overridden DefaultTableCellRenderer method.
	 */
	public Component getTableCellRendererComponent(
		JTable table,
		Object value,
		boolean isSelected,
		boolean hasFocus,
		int row, 
		int column
		) {
		
		// Get component, after changes have been made by base class.
		Component c = super.getTableCellRendererComponent(
			table,
			value, 
			isSelected, 
			hasFocus, 
			row, 
			column
			);		
		
		// Make modifications, BUT only if value object is a Record object.
		// (Should be if renderer has been registered correctly with Table.)
		if (value instanceof Record) {
			
			Record record = (Record)value;
			JLabel label = (JLabel)c;
			label.setText(record.getName());
			label.setIcon(getSelectionIcon(record));
			}

		return c;
			
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	// Returns icon on basis of selection status of supplied record.
	private ImageIcon getSelectionIcon(Record record) {
		
		RecordType recordType = record.getRecordType();
		if (record.getRecordType() == RecordType.Target) {
			return getTargetSelectionIcon(record);
			}
		else {
			return getNonTargetSelectionIcon(record);
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private ImageIcon getTargetSelectionIcon(Record record) {
		
		RecordStatus selectionStatus = record.getSelectionStatus();
		RecordStatus matchStatus = record.getMatchStatus();
		
		// Action if a node (taxon).
		if (!record.isLeaf()) {
			
			// Node not selected.
			if (selectionStatus == RecordStatus.NotSelected) {
				return KeaIcon.ClosedNoneSelected.getImageIcon();
				}
			
			// Node is selected...
			else if (selectionStatus == RecordStatus.Selected) {
				
				// ...yet not relevant.
				if (matchStatus == RecordStatus.NotRelevant) {
					return KeaIcon.TargetClosedAllSelectedNoneRelevant.getImageIcon();
					}
				
				// ...and matched.
				else if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.TargetClosedAllSelectedAllHit.getImageIcon();
					}
				
				// ...and partially matched.
				else if (matchStatus == RecordStatus.PartiallyMatched) {
					return KeaIcon.TargetClosedAllSelectedSomeHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.TargetClosedAllSelectedNoneHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
			
			// Node is partially selected...
			else if (selectionStatus == RecordStatus.PartiallySelected) {
				
				// ... yet not relevant.
				if (matchStatus == RecordStatus.NotRelevant) {
					return KeaIcon.TargetClosedSomeSelectedNoneRelevant.getImageIcon();
					}
				
				// ...and matched.
				else if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.TargetClosedSomeSelectedAllHit.getImageIcon();
					}
				
				// ...and partially matched.
				else if (matchStatus == RecordStatus.PartiallyMatched) {
					return KeaIcon.TargetClosedSomeSelectedSomeHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.TargetClosedSomeSelectedNoneHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
			
			} // End of if.
		
		// Action if a leaf (organism entry).
		else {
			
			// Record not relevant.
			if (matchStatus == RecordStatus.NotRelevant) {
				return KeaIcon.TargetRecordNotRelevant.getImageIcon();
				}
			
			// Record not selected.
			else if (selectionStatus == RecordStatus.NotSelected) {
				return KeaIcon.RecordNotSelected.getImageIcon();
				}
			
			// Record is selected...
			else if (selectionStatus == RecordStatus.Selected) {
				
				// ...and matched.
				if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.TargetRecordHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.TargetRecordNotHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
				
			} // End of else.
		
		return null;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private ImageIcon getNonTargetSelectionIcon(Record record) {
		
		RecordStatus selectionStatus = record.getSelectionStatus();
		RecordStatus matchStatus = record.getMatchStatus();
		
		// Action if a node (taxon).
		if (!record.isLeaf()) {
			
			// Node not selected.
			if (selectionStatus == RecordStatus.NotSelected) {
				return KeaIcon.ClosedNoneSelected.getImageIcon();
				}
			
			// Node is selected...
			else if (selectionStatus == RecordStatus.Selected) {
				
				// ...yet not relevant.
				if (matchStatus == RecordStatus.NotRelevant) {
					return KeaIcon.ClosedAllSelectedNoneRelevant.getImageIcon();
					}
				
				// ...and matched.
				else if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.ClosedAllSelectedAllHit.getImageIcon();
					}
				
				// ...and partially matched.
				else if (matchStatus == RecordStatus.PartiallyMatched) {
					return KeaIcon.ClosedAllSelectedSomeHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.ClosedAllSelectedNoneHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
			
			// Node is partially selected...
			else if (selectionStatus == RecordStatus.PartiallySelected) {
				
				// ... yet not relevant.
				if (matchStatus == RecordStatus.NotRelevant) {
					return KeaIcon.ClosedSomeSelectedNoneRelevant.getImageIcon();
					}
				
				// ...and matched.
				else if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.ClosedSomeSelectedAllHit.getImageIcon();
					}
				
				// ...and partially matched.
				else if (matchStatus == RecordStatus.PartiallyMatched) {
					return KeaIcon.ClosedSomeSelectedSomeHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.ClosedSomeSelectedNoneHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
			
			} // End of if.
		
		// Action if a leaf (organism entry).
		else {
			
			// Record not relevant.
			if (matchStatus == RecordStatus.NotRelevant) {
				return KeaIcon.RecordNotRelevant.getImageIcon();
				}
			
			// Record not selected.
			else if (selectionStatus == RecordStatus.NotSelected) {
				return KeaIcon.RecordNotSelected.getImageIcon();
				}
			
			// Record is selected...
			else if (selectionStatus == RecordStatus.Selected) {
				
				// ...and matched.
				if (matchStatus == RecordStatus.Matched) {
					return KeaIcon.RecordHit.getImageIcon();
					}
				
				// ...and not matched.
				else if (matchStatus == RecordStatus.NotMatched) {
					return KeaIcon.RecordNotHit.getImageIcon();
					}
				
				// ERROR.
				else {
					throw new IllegalArgumentException(
						"Record '" + record.getName()+ "' has an illegal" +
						" match status: " + matchStatus.toString()
						);
					}
				}
				
			} // End of else.
		
		return null;
		
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
