// ReportTester.java created on 25 May 2004 at 15:06

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;
import java.lang.*;

import kea.programs.text.*;
import kea.database.*;
import kea.programs.dialogBoxes.databaseDialog.*;
import kea.programs.dialogBoxes.*;
import kea.sequences.nucleicAcid.*;
import kea.exceptions.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 
 @author  Kevin Ashelford
 @version 2.17
 */
class ReportTester extends JFrame {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private final Database _database;
	private OligoField _oligoField;
	
	//##########################################################################
	
	// ENTRY POINT
	
	/**
	 Entry point for program.
	 @param args the command line arguments
	 */
	public static void main(String[] args) {
		kea.programs.LookAndFeelManager.setLookAndFeel();
		new ReportTester();
		} // End of main.
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>ReportTester</code>.
	 */
	public ReportTester() {
		
		_database = DatabaseFactory.createDatabase();
		
		initialise();
		pack();
		kea.util.GUIUtils.setLocationOnceSized(this);
		kea.util.GUIUtils.setWindowMinimumSize(this, getSize());
		setVisible(true);
		
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS
	
	private void initialise() {
		
		this.setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		
		JPanel mainPanel = (JPanel)this.getContentPane();
		mainPanel.setLayout(new GridLayout(4, 1, 5, 5));
		
		// Select database button.
		JButton databaseButton = new JButton(new DatabaseAction());
		mainPanel.add(databaseButton);
		
		// Seslect targets button.
		JButton targetButton = new JButton(new TargetAction());
		mainPanel.add(targetButton);
		
		// Enter oligo text field.
		_oligoField = new OligoField();
		mainPanel.add(_oligoField);
		
		// Go to report button.
		JButton reportButton = new JButton(new ReportAction());
		mainPanel.add(reportButton);
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	public void selectDatabase() {
		
		OpenDatabaseDialog odd = new OpenDatabaseDialog(this, _database);
		odd.setTitle("Select Database Dialog");
		
		if (odd.showDatabaseDialog() == DialogResult.Ok) {
			// Disable / enable buttons?
			}
		else {
			// Disable / enable buttons
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	public void selectTargets() {
		
		SimpleChooseTargetDialog ctd = 
			new SimpleChooseTargetDialog(this, _database, null);
		ctd.setTitle("Choose target records");
		
		if (ctd.showDialog() == DialogResult.Ok) {
			// Disable / enable buttons.
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	public void getReport() {
		
		PrimroseOligo oligo = null;
		
		try {
			oligo = new PrimroseOligo(
			_oligoField.getOligo().getSequenceString(), 
			Orientation.SENSE
			);
			} 
		catch(NonIUBCharacterException nice) {
			nice.printStackTrace(); //<+++++++++++++++++++++++++++++++++++++++++++++++ expand!
			}
		catch(IllegalSequenceException ise) {	
			ise.printStackTrace(); //<+++++++++++++++++++++++++++++++++++++++++++++++ expand!
			}
		catch(NullSequenceException nse) {
			nse.printStackTrace(); //<+++++++++++++++++++++++++++++++++++++++++++++++ expand!
			}
		catch(Exception e) {
			e.printStackTrace(); //<+++++++++++++++++++++++++++++++++++++++++++++++ expand!
			}
		
		
		///*
		Report report = new Report( 
			this, 
			oligo, 
			_database 
			);
		report.showDialog(); 
		//*/
		
		//ReportDialog report = new ReportDialog(this, oligo, _database);
		//report.showDialog(); 
		
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASSES
	
	private class DatabaseAction extends AbstractAction {
		
		public DatabaseAction() {
			putValue(Action.NAME, "Load database");
			} 
		
		public void actionPerformed(ActionEvent e) {
			selectDatabase();
			}
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class TargetAction extends AbstractAction {
		
		public TargetAction() {
			putValue(Action.NAME, "Select Targets");
			} 
		
		public void actionPerformed(ActionEvent e) {
			selectTargets();
			}
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class ReportAction extends AbstractAction {
		
		public ReportAction() {
			putValue(Action.NAME, "Get report");
			}
		
		public void actionPerformed(ActionEvent e) {
			getReport();
			}
		
		} // End of inner class.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
