// ReportTreeCellRenderer.java created on 26 May 2004 at 14:12

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.tree.*;
import javax.swing.*;
import java.awt.*;

import kea.programs.*;
import kea.database.*;
import kea.programs.icons.KeaIcon;
import kea.graphics.Colour;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Supplies customised tree icons and colour scheme for ResultsDialog.
 @author  Kevin Ashelford.
 @version 2.17.
 */
class ReportTreeCellRenderer extends DefaultTreeCellRenderer {
	
	//##########################################################################
	
	// MEMBER FIELDS

	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 */
	public ReportTreeCellRenderer() {
		
		super.setBackgroundSelectionColor(
			Colour.BackgroundSelection
			);
		
		// Necessary to prevent problems with display.
		super.setTextNonSelectionColor(Color.BLACK);
		super.setTextSelectionColor(Color.BLACK);
		
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS

	/**
	 Overriden base method.
	 @param tree JTree.
	 @param value TreeNode.
	 @param selected Is node selected?
	 @param expanded Is node expanded?
	 @param leaf Is node a leaf?
	 @param row Tree row.
	 @param hasFocus Has focus?
	 @return Component.
	 */
	public Component getTreeCellRendererComponent(
		JTree tree,
		Object value,
		boolean selected,
		boolean expanded,
		boolean leaf,
		int row,
		boolean hasFocus
		) {
		
		// Only want to change icons!	
		super.getTreeCellRendererComponent(
			tree, 
			value, 
			selected, 
			expanded, 
			leaf, 
			row, 
			hasFocus
			);
		
		// On basis of record selection status choose icon image to display.
		Record r = (Record)value;
		if (r.getSelectionStatus() == RecordStatus.Selected) {
			if (r.getRecordType() == RecordType.Target) {
				selectedTargetRecord(r, expanded, leaf);
				} 
			else {
				selectedRecord(r, expanded, leaf);
				}
			
			}
		else if (r.getSelectionStatus() == RecordStatus.PartiallySelected) {
			if (r.getRecordType() == RecordType.Target) {
				partiallySelectedTargetRecord(r, expanded);
				} 
			else {
				partiallySelectedRecord(r, expanded);
				}
			}
		else {
			notSelectedRecord(expanded, leaf);
			}
		
		return this;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void selectedRecord(Record record, boolean expanded, boolean leaf) {
		
		// Open node.
		if (expanded) {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.OpenAllSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.OpenAllSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.OpenAllSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.OpenAllSelectedSomeHit.getImageIcon());
				}
			
			}
		
		// Leaf.
		else if (leaf) {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.RecordNotRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.RecordHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.RecordNotHit.getImageIcon());
				}
			
			}
		// Closed Node
		else {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.ClosedAllSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.ClosedAllSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.ClosedAllSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.ClosedAllSelectedSomeHit.getImageIcon());
				}
			
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void selectedTargetRecord(Record record, boolean expanded, boolean leaf) {
		
		// Open node.
		if (expanded) {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.TargetOpenAllSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.TargetOpenAllSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.TargetOpenAllSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.TargetOpenAllSelectedSomeHit.getImageIcon());
				}
			
			}
		
		// Leaf.
		else if (leaf) {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.TargetRecordNotRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.TargetRecordHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.TargetRecordNotHit.getImageIcon()); 
				}
			
			}
		// Closed Node
		else {
			
			// Not selected.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.TargetClosedAllSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.TargetClosedAllSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.TargetClosedAllSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.TargetClosedAllSelectedSomeHit.getImageIcon());
				}
			
			}
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void partiallySelectedRecord(Record record, boolean expanded) {
		
		// Open node.
		if (expanded) {
			
			// Not relevant.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.OpenSomeSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.OpenSomeSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.OpenSomeSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.OpenSomeSelectedSomeHit.getImageIcon());
				}
			
			}
		
		// Closed Node
		else {
			
			// Not relevant.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.ClosedSomeSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.ClosedSomeSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.ClosedSomeSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.ClosedSomeSelectedSomeHit.getImageIcon());
				}
			
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void partiallySelectedTargetRecord(Record record, boolean expanded) {
		
		// Open node.
		if (expanded) {
			
			// Not relevant.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.TargetOpenSomeSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.TargetOpenSomeSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.TargetOpenSomeSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.TargetOpenSomeSelectedSomeHit.getImageIcon());
				}
			
			}
		
		// Closed Node
		else {
			
			// Not relevant.
			if (record.getMatchStatus() == RecordStatus.NotRelevant) {
				this.setIcon(KeaIcon.TargetClosedSomeSelectedNoneRelevant.getImageIcon());
				}
			
			// Matched.
			else if (record.getMatchStatus() == RecordStatus.Matched) {
				this.setIcon(KeaIcon.TargetClosedSomeSelectedAllHit.getImageIcon());
				}
			
			// Not matched.
			else if (record.getMatchStatus() == RecordStatus.NotMatched) {
				this.setIcon(KeaIcon.TargetClosedSomeSelectedNoneHit.getImageIcon());
				}
			
			// Partially matched.
			else if (record.getMatchStatus() == RecordStatus.PartiallyMatched) {
				this.setIcon(KeaIcon.TargetClosedSomeSelectedSomeHit.getImageIcon());
				}
			
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void notSelectedRecord(boolean expanded, boolean leaf) {
		
		if (expanded) {
			this.setIcon(KeaIcon.OpenNoneSelected.getImageIcon());
			}
		else if (leaf) {
			this.setIcon(KeaIcon.RecordNotSelected.getImageIcon());
			}
		else {
			this.setIcon(KeaIcon.ClosedNoneSelected.getImageIcon());
			}
		
		} // End of method.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
