// SearchDatabaseDialogTableModel.java created on 16 May 2004 at 11:10

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;
import javax.swing.table.*;
import javax.swing.*;
import java.io.*;

import kea.database.*;
import kea.sequences.nucleicAcid.tm.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Table model for SearchDatabaseDialog dialog box.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class SearchDatabaseDialogTableModel extends AbstractTableModel {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	// Column names used by AbstractTreeModel getColumnName() method.
	private final String[] _columnNames;
	// Column Class types used by AbstractTreeModel getColumnClass() method.
	private final Class[] _columnClasses;
	
	private PrimroseOligo[] _oligos;

	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 @param oligos Array of oligo objects to display.
	 */
	public SearchDatabaseDialogTableModel(
		final PrimroseOligo[] oligos
		) {
			
		_columnNames = new String[]{
			"No.",					// 0
			"Oligonucleotide (5'-sense-3')",		// 1
			"Hits",					// 2
			"Target",				// 3
			"% target",				// 4
			"Non-target",			// 5
			"% non-target",			// 6
			"Tm",					// 7
			"%GC",					// 8
			"Degeneracy"			// 9
			};
		_columnClasses = new Class[] {
			Integer.class,			// 0
			Oligo.class,			// 1
			Integer.class,			// 2
			Integer.class,			// 3
			Float.class,			// 4
			Integer.class,			// 5
			Float.class,			// 6
			Float.class,			// 7
			Float.class,			// 8
			Integer.class			// 9
			};
		
		
		updateModel(oligos);
			
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Update model with new Record object.
	 */
	public void updateModel(PrimroseOligo[] oligos) {
		_oligos = oligos;
		fireTableChanged(null);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	public void clear() {
		updateModel(new PrimroseOligo[0]);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	// Gets source name from File object associated with Record object.
	private String getSourceName(final Record record) {
		return kea.util.FileIO.getNameWithoutSuffix(record.getSource());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AbstractTableModel method.
	 @return Number of columns.
	 */
	public int getColumnCount() {
		return _columnClasses.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementaion of AbstractTableModel method.
	 @return Number of rows.
	 */
	public int getRowCount() {
		return _oligos.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AstractTableModel method.
	 @param rowIndex Row index number for cell.
	 @param columnIndex Column index number for cell.
	 @return Object.
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		
		PrimroseOligo oligo = _oligos[rowIndex]; 

		switch (columnIndex) {
			
			case 0: return new Integer(rowIndex + 1);
			case 1: return oligo;
			case 2: return new Integer(oligo.getHits());
			case 3: return new Integer(oligo.getTargetHits());
			case 4: return getPercentTargetHits(oligo);
			case 5: return new Integer(oligo.getNonTargetHits());
			case 6: return getPercentNonTargetHits(oligo);
			case 7: return getMeltingTemperature(oligo);
			case 8: return new Float(oligo.getPercentGCContent());
			case 9: return new Integer(oligo.getDegeneracy());
		
			default: return null;
			
			} // End of switch.
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private Float getMeltingTemperature(PrimroseOligo oligo) {
		
		return new Float(oligo.getMeltingTemperature(TmCalculatorType.ChesterMarshak));
		
		//return _numberFormat.format(
		//	oligo.getMeltingTemperature(TmCalculatorType.ChesterMarshak)
		//	);
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private Float getPercentTargetHits(PrimroseOligo oligo) {
		
		return new Float(oligo.getPercentTargetHits());
		
		//return _numberFormat.format(oligo.getPercentTargetHits());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private Float getPercentNonTargetHits(PrimroseOligo oligo) {
		
		return new Float(oligo.getPercentNonTargetHits());
		
		//return _numberFormat.format(oligo.getPercentNonTargetHits());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Column name as a String.
	 */
	public String getColumnName(int columnIndex) {
		return _columnNames[columnIndex];
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Class object for column.
	 */
	public Class getColumnClass(int columnIndex) {
		return _columnClasses[columnIndex];
		} // End of method.

	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
