// SelectedTargetsTableModel.java created on 17 May 2004 at 10:50

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;
import javax.swing.table.*;
import javax.swing.*;
import java.io.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 
 @author  Kevin Ashelford.
 @version 2.17.
 */
class SelectedTargetsTableModel extends AbstractTableModel {
	
	//##########################################################################
	
	// MEMBER FIELDS
	
	// Column names used by AbstractTreeModel getColumnName() method.
	private final String[] _columnNames;
	// Column Class types used by AbstractTreeModel getColumnClass() method.
	private final Class[] _columnClasses;
	
	private final Target[] _targets;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 @param targetCollection Targets to display.
	 */
	public SelectedTargetsTableModel(final Target[] targets) {
		
		_columnNames = new String[]{
			"Name", 
			"Code",
			"Source"
			};
		_columnClasses = new Class[] {
			Record.class,
			String.class,
			String.class
			};
			
		_targets = targets;	
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS
	
	// Gets source name from File object associated with Record object.
	private String getSourceName(final Record record) {
		return kea.util.FileIO.getNameWithoutSuffix(record.getSource());
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AbstractTableModel method.
	 @return Number of columns.
	 */
	public int getColumnCount() {
		return _columnClasses.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementaion of AbstractTableModel method.
	 @return Number of rows.
	 */
	public int getRowCount() {
		return _targets.length;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Implementation of AstractTableModel method.
	 @param rowIndex Row index number for cell.
	 @param columnIndex Column index number for cell.
	 @return Object.
	 */
	public Object getValueAt(int rowIndex, int columnIndex) {
		
		Target target = _targets[rowIndex];
		
		switch (columnIndex) {
			
			case 0: return target.getRecord();
			case 1: return target.getRecord().getCode();
			case 2: return getSourceName(target.getRecord());
		
			default: return null;
			
			} // End of switch.
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////

	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Column name as a String.
	 */
	public String getColumnName(int columnIndex) {
		return _columnNames[columnIndex];
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Overridden AbstractTableModel method.
	 @param columnIndex Column index number.
	 @return Class object for column.
	 */
	public Class getColumnClass(int columnIndex) {
		return _columnClasses[columnIndex];
		} // End of method.

	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////