// Temp.java created on 12 March 2004 at 13:05

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.io.*;
import javax.swing.tree.*;
import java.util.*;


import kea.programs.dialogBoxes.databaseDialog.*;
import kea.database.*;
import kea.programs.dialogBoxes.*;
import kea.programs.icons.KeaIcon;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Dialog box for selecting target records.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class SimpleChooseTargetDialog extends AbstractTreeAndTableDatabaseDialog {
	
	//##########################################################################
	
	// CLASS FIELDS

	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private JTable _table;
	private Database _database;
	private JFrame _owner;
	private JMenu _helpMenu;
	
	private boolean _rootVisible;
	private RootVisibleAction _rootVisibleAction;
	
	private DialogResult _dialogResult;
	private JTree _tree;
	private Stack _memory;
	
	private final Action _notepadAction;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of class.
	 @param owner Owner window.
	 @param database Database object to display.
	 */
	public SimpleChooseTargetDialog(
		final JFrame owner, 
		final Database database, 
		final Action notepadAction) {
			
		super(owner, database);
		
		_notepadAction = notepadAction;
		
		_rootVisible = false;
		_rootVisibleAction = new RootVisibleAction();
		_tree = getTree();
		_table = getTable();
		_owner = owner;
		_database = database;
		_memory = new Stack();
		
		// Prevent further modification of record selection status.
		enableRecordSelection(false);
		
		// Add components to basic component.
		setJMenuBar(initialiseMenuBarComponent());
		addToolBar(initialiseToolBarComponent());
		addButtonPanel(initialiseButtonPanelComponent());
		
		
		// Register listeners to allow user to mark/unmark records as targets.
		_tree.addMouseListener(new TreeMouseListener());
		_table.addMouseListener(new TableMouseListener());
		
		_tree.setCellRenderer(new ChooseTargetDialogTreeCellRenderer());
		_table.setDefaultRenderer(
			Record.class, 
			new ChooseTargetDialogTableCellRenderer()
			);
		
		} // End of constructor.
	
	//##########################################################################
	
	// PROPERTY ACCESSOR METHODS
	
	//##########################################################################
	
	// METHODS

	/**
	 Displays dialog.
	 @return Returns DialogResult enum according to button pressed by user.
	 */
	public DialogResult showDialog() {
		
		setVisible(true);
		return _dialogResult;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private JToolBar initialiseToolBarComponent() {
		
		JToolBar toolBar;
		
		toolBar = new JToolBar();
		toolBar.setRollover(true);
		toolBar.add(_rootVisibleAction);
		toolBar.add(_notepadAction);
		toolBar.addSeparator();
		
		return toolBar;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private JPanel initialiseButtonPanelComponent() {
		
		JPanel panel = new JPanel();
		panel.setBorder(new EmptyBorder(5, 5, 5, 5));
		panel.setLayout(new GridLayout(1, 3, 5, 5));
		
		JButton okButton = new JButton(new OkAction());
		panel.add(okButton);
		okButton.setPreferredSize(new Dimension(100, 30));
		
		JButton cancelButton = new JButton(new CancelAction());
		panel.add(cancelButton);
		
		JButton resetButton = new JButton(new ResetAction());
		panel.add(resetButton);
		
		return panel;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private JMenuBar initialiseMenuBarComponent() {
		
		JMenuBar menuBar = new JMenuBar();
		menuBar.setBorder(new EmptyBorder(0,0,0,0));
		
		// File.
		JMenu fileMenu = new JMenu("File");
		menuBar.add(fileMenu);
		fileMenu.getAccessibleContext().setAccessibleName("File");
		fileMenu.setMnemonic(KeyEvent.VK_F);
		fileMenu.add(new ExitAction());
		
		// Options.
		JMenu optionsMenu = new JMenu("Options");
		menuBar.add(optionsMenu);
		optionsMenu.getAccessibleContext().setAccessibleName("Options");
		optionsMenu.setMnemonic(KeyEvent.VK_O);
		optionsMenu.add(_rootVisibleAction);
		
		// Help.
		_helpMenu = new JMenu("Help");
		menuBar.add(_helpMenu);
		_helpMenu.getAccessibleContext().setAccessibleName("Help");
		_helpMenu.setMnemonic(KeyEvent.VK_H);
		
		return menuBar;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Use this method to add menu items (Actions) to the help menu.
	 @param action Action to add.
	 */
	public void addHelpMenuAction(AbstractAction action) {
		_helpMenu.add(action);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void toggleTargetStatus(Record record) {
		
		// Determine opposite of current record's target status.
		RecordType type = RecordType.Target;
		if (record.getRecordType() == RecordType.Target) {
			type = RecordType.Standard;
			}
		
		// Recursively mark record and descendants with appropriate target status.
		setTargetStatus(record, type);
		
		// Repaint tree so that changes instigated by the TreeCellRenderer
		// are seen immediately after mouse-click.
		_tree.repaint();
		
		// Notify anything that's listening that change has occurred.
		fireOnTreeNodeSelectionToggle(record);
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void setTargetStatus(Record record ,RecordType type) {
		
		// remember previous status just in case need to cancel changes.
		if (type == RecordType.Target) {
			_memory.add(new MemoryItem(record, RecordType.Standard));
			}
		else {
			_memory.add(new MemoryItem(record, RecordType.Target));
			}
		
		// Only mark selected records.
		if (
			record.getSelectionStatus() == RecordStatus.Selected ||
			record.getSelectionStatus() == RecordStatus.PartiallySelected
			) 
			record.setRecordType(type);
		
		Record[] children = record.getChildrenAsRecords();
		for (int i = 0; i < children.length; i++) {
			setTargetStatus(children[i], type);
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private void undoChanges() {
		
		while(!_memory.empty()) {
			MemoryItem mi = (MemoryItem)_memory.pop();
			mi.getRecord().setRecordType(mi.getRecordType());
			}
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	private int numberOfRecordsSelected() {
		
		int counter = 0;
		
		Record[] records = _database.getRecords();
		for (int i = 0; i < records.length; i++) {
			if (records[i].getRecordType() == RecordType.Target) counter++;
			}
		
		return counter;
		
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASS
	
	private class MemoryItem {
		
		private Record record;
		private RecordType type;
		
		public MemoryItem(Record record, RecordType type) {
			this.record = record;
			this.type = type;
			}
		
		public Record getRecord() {return record;}
		public RecordType getRecordType() {return type;}
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	// Open record within table and expand tree.
	private class TableMouseListener extends MouseAdapter {
		
		public void mouseClicked(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		public void mouseEntered(MouseEvent me) {
			}
		
		public void mouseExited(MouseEvent me) {
			}
		
		public void mousePressed(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		public void mouseReleased(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		
		//=====================================================
		
		private void targetRecordToggle(MouseEvent me) {
			
			int rowIndex = _table.rowAtPoint(me.getPoint());
			int columnIndex = _table.columnAtPoint(me.getPoint());
			
			Object o = _table.getModel().getValueAt(rowIndex, columnIndex);
			
			if (o instanceof Record) {
				Record r = (Record)o;
				
				toggleTargetStatus(r);

				}
			}
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	// Marks records as targeted or not targeted.
	private class TreeMouseListener implements MouseListener {
		
		public void mouseClicked(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		public void mouseEntered(MouseEvent me) {
			}
		
		public void mouseExited(MouseEvent me) {
			}
		
		public void mousePressed(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		public void mouseReleased(MouseEvent me) {
			if (me.isPopupTrigger()) {targetRecordToggle(me);}
			}
		
		//=====================================================
		
		private void targetRecordToggle(MouseEvent me) {
			
			TreePath tp = _tree.getClosestPathForLocation(me.getX(), me.getY());
			if (tp == null) {return;}
			Record r = (Record)tp.getLastPathComponent();
			
			toggleTargetStatus(r);
		
			} 
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class RootVisibleAction extends AbstractAction {
		
		public RootVisibleAction() {
			putValue(Action.NAME, "Show Root");
			putValue(Action.SHORT_DESCRIPTION, "Displays root icon at base of tree.");
			putValue(Action.MNEMONIC_KEY, new Integer(KeyEvent.VK_R));
			putValue(
				Action.ACCELERATOR_KEY,
				KeyStroke.getKeyStroke(KeyEvent.VK_R, InputEvent.CTRL_DOWN_MASK)
				);
			putValue(
				Action.SMALL_ICON, 
				kea.programs.dialogBoxes.databaseDialog.Info.ROOT_VISIBLE_ICON
				);
			} 
		
		public void actionPerformed(ActionEvent e) {
			_rootVisible = !_rootVisible;
			_tree.setRootVisible(_rootVisible);
			}		
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	// Exit.
	private class ExitAction extends AbstractAction {
		public ExitAction() {
			putValue(Action.NAME, "Exit");
			putValue(
				Action.SHORT_DESCRIPTION, 
				"Exit dialog and returns to main window."
				);
			putValue(Action.MNEMONIC_KEY, new Integer(KeyEvent.VK_X));
			putValue(Action.SMALL_ICON, Info.getExitIcon());
			} 
		public void actionPerformed(ActionEvent ae) {
			
			undoChanges();
			_dialogResult = DialogResult.Cancel;
			
			WindowEvent we = new WindowEvent(
				SimpleChooseTargetDialog.this, 
				WindowEvent.WINDOW_CLOSING
				);
			processWindowEvent(we);
			} 
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class OkAction extends AbstractAction {
		public OkAction() {
			putValue(Action.NAME, "Accept");
			putValue(Action.SHORT_DESCRIPTION, "Accept changes made.");
			putValue(Action.MNEMONIC_KEY, new Integer(KeyEvent.VK_A));
			putValue(Action.SMALL_ICON, KeaIcon.Ok.getImageIcon());
			} 
		
		public void actionPerformed(ActionEvent e) {
			
			final int numberOfTargets = numberOfRecordsSelected();
			
			// Action if no records chosen.
			if (numberOfTargets == 0) {
				
				JOptionPane.showMessageDialog(
					SimpleChooseTargetDialog.this, 
					"No records have been selected!", 
					"Error!", 
					JOptionPane.ERROR_MESSAGE
					);
				
				return;
				}
				
			// Number of target records ok. Proceed...
			_dialogResult = DialogResult.Ok;
			setVisible(false);
			dispose();
			}		
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class CancelAction extends AbstractAction {
		
		public CancelAction() {
			putValue(Action.NAME, "Cancel");
			putValue(Action.SHORT_DESCRIPTION, "Cancel changes made.");
			putValue(Action.MNEMONIC_KEY, new Integer(KeyEvent.VK_C));
			putValue(Action.SMALL_ICON, KeaIcon.Cancel.getImageIcon());
			}
		
		public void actionPerformed(ActionEvent e) {
			undoChanges();
			_dialogResult = DialogResult.Cancel;
			setVisible(false);
			dispose();
			}
		
		} // End of inner class.
	
	//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
	
	private class ResetAction extends AbstractAction {
		
		public ResetAction() {
			putValue(Action.NAME, "Reset");
			putValue(
				Action.SHORT_DESCRIPTION, 
				"Resets all records to non-target status."
				);
			putValue(Action.MNEMONIC_KEY, new Integer(KeyEvent.VK_R));
			putValue(Action.SMALL_ICON, KeaIcon.Reset.getImageIcon());
			} 
		
		public void actionPerformed(ActionEvent e) {
			setTargetStatus(_database.getRootRecord(), RecordType.Standard);
			_dialogResult = DialogResult.Reset;
			_tree.repaint();
			fireOnTreeNodeSelectionToggle(_database.getRootRecord());
			_memory.clear();
			}
		
		} // End of inner class.
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
