// Target.java created on 15 May 2004 at 09:39

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

import kea.database.*;
import kea.programs.icons.KeaIcon;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Simple class for holding target record and associated information, for use with
 FindOligosDialog.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public final class Target {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private final Record _record;
	private boolean _selected;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>Target</code>.
	 @param record Target record object.
	 @param selected If true, record is used to generate oligonucleotides.
	 */
	public Target(final Record record, final boolean selected) {
		_record = record;
		_selected = selected;
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Clones supplied Target object. That is, a new Target object with the same
	 Record and selection status is generated.
	 @param target Target object to clone.
	 @return Clone of original Target object.
	 */
	public static Target clone(Target target) {
		
		return new Target(target.getRecord(), target.isSelected());
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns target record.
	 @return Target record.
	 */
	public Record getRecord() {
		return _record;
		} // end of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns true if target record is to be used in oligonucleotide generation.
	 @return True if record is to be used.
	 */
	public boolean isSelected() {
		return _selected;
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////

	/**
	 Toggles selection status of target.
	 */
	public void toggleSelection() {
		
		_selected = !_selected;
		
		} // End of method.

	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns string representation of object.
	 @return String object.
	 */
	public String toString() {
		
		return 
			_record.getName() + 
			" (" 
			+ _record.getCode() + 
			"), selected=" + _selected;
		
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASSES

	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
