// TargetCollection.java created on 15 May 2004 at 09:48

//=============================================================================
//
//    Copyright (C) 2004 Kevin Ashelford
//    Contact details:
//    Email: ashelford@cardiff.ac.uk
//    Address:  Cardiff School of Bioscience, Cardiff University, PO. Box 915,
//    Cardiff, UK. CF10 3TL
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//=============================================================================

package kea.programs.jPrimrose;

import java.lang.*;
import java.util.*;

import kea.database.*;

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

/**
 Stores target objects.
 @author  Kevin Ashelford.
 @version 2.17.
 */
public class TargetCollection {
	
	//##########################################################################
	
	// CLASS FIELDS
	
	////////////////////////////////////////////////////////////////////////////
	
	// MEMBER FIELDS
	
	private final ArrayList _store;
	
	//##########################################################################
	
	// CONSTRUCTOR
	
	/**
	 Creates a new instance of <code>TargetCollection</code>.
	 */
	public TargetCollection() {
		_store = new ArrayList();
		} // End of constructor.
	
	//##########################################################################
	
	// METHODS
	
	/**
	 Adds target to collection.
	 @param target Target object to add.
	 */
	public void addTarget(final Target target) {
		_store.add(target);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns Target object corresponding to supplied Record.
	 @param record Record object of required Target.
	 @return Target object.
	 */
	public Target getTarget(final Record record) {
		
		for (int i = 0; i < _store.size(); i++) {
			
			Target t = (Target)_store.get(i);
			
			if (t.getRecord() == record) {
				return t;
				}
			}
		
		return null;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns target at position specified.
	 @param index Index number of required target.
	 @return Target object.
	 */
	public Target getTarget(final int index) {
		return (Target)_store.get(index);
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns number of Target objects in collection.
	 @return Size of collection.
	 */
	public int getSize() {
		return _store.size();
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns number of selected targets within collection.
	 @return Number selected.
	 */
	public int getNumberSelected() {
		
		int counter = 0;
		for(int i = 0; i < _store.size(); i++) {
			Target t = (Target)_store.get(i);
			if (t.isSelected()) {counter++;}
			}
		return counter;
		
		} // End of method.
	
	////////////////////////////////////////////////////////////////////////////
	
	/**
	 Returns array of all target objects that are selected.
	 @return Array of selected target objects.
	 */
	public Target[] getSelectedTargets() {
		
		ArrayList buffer = new ArrayList();
		
		for (int i =0; i < _store.size(); i++) {
			Target t = (Target)_store.get(i);
			if (t.isSelected()) {
				buffer.add(t);
				}
			}
		
		Target[] selectedTargets = new Target[buffer.size()];
		buffer.toArray(selectedTargets);
		return selectedTargets;
		
		} // End of method.
	
	//##########################################################################
	
	// INNER CLASSES
	
	//##########################################################################
	
	} // End of class.

////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
